@@ -1,7 +1,10 @@
 #!/usr/bin/perl -w
 use strict;
+use warnings;
 use DBIx::RunSQL;
 
+our $VERSION = '0.21';
+
 my $exitcode = DBIx::RunSQL->handle_command_line('myapp', \@ARGV);
 exit $exitcode;
 
@@ -61,6 +64,8 @@ Use a different formatter for table output. Supported formatters are
 
   Text::Table - output results as ASCII table
 
+  Text::Table::Any - output results as various formats
+
 =item C<--force>
 
 Don't stop on errors
